Jumeaux Document
================

!!! danger "Support languages"

    Now we support only for Japanese except for this page and TOC.

[![pypi](https://img.shields.io/pypi/v/jumeaux.svg)](https://pypi.org/project/jumeaux/) [![Versions](https://img.shields.io/pypi/pyversions/jumeaux.svg)](https://pypi.org/project/jumeaux/) [![Actions Status](https://github.com/tadashi-aikawa/jumeaux/workflows/Tests/badge.svg)](https://github.com/tadashi-aikawa/jumeaux/actions) [![codecov](https://codecov.io/gh/tadashi-aikawa/jumeaux/branch/master/graph/badge.svg)](https://codecov.io/gh/tadashi-aikawa/jumeaux) [![license](https://img.shields.io/github/license/mashape/apistatus.svg)](https://github.com/tadashi-aikawa/jumeaux/blob/master/LICENSE)


<img src="./img/logo-large.png" width=480 />

**Jumeaux** can check differences between two responses of API.

* GitHub -> https://github.com/tadashi-aikawa/jumeaux
* PyPI -> https://pypi.python.org/pypi/jumeaux

<video controls src="https://dl.dropboxusercontent.com/s/2m0jvenb50iyacr/demo.mp4" type="video/mp4" width="1200"></video>

!!! hint "If you want to check more graphical with GUI tools, Use [Miroir]."

[Miroir]: https://github.com/tadashi-aikawa/miroir
